@@ -1,7 +1,7 @@
 /*****************************************************************
  * gavl - a general purpose audio/video processing library
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -235,8 +235,8 @@ gavl_interleave_context_create(gavl_audio_options_t * opt,
 
   table = gavl_create_interleave_table(opt);
   ret->func =
-    gavl_find_interleave_converter(table, &(ret->input_format),
-                                   &(ret->output_format));
+    gavl_find_interleave_converter(table, &ret->input_format,
+                                   &ret->output_format);
   
   gavl_destroy_interleave_table(table);
   return ret;
