@@ -1,7 +1,7 @@
 /*****************************************************************
  * gavl - a general purpose audio/video processing library
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -113,6 +113,9 @@ void gavl_video_scale_table_init(gavl_video_scale_table_t * tab,
 
   widen = 0;
 
+  if(!dst_size)
+    return;
+  
   if(scale_factor < 1.0)
     {
     switch(opt->downscale_filter)
@@ -148,7 +151,7 @@ void gavl_video_scale_table_init(gavl_video_scale_table_t * tab,
   /* Get the kernel generator */
 
   weight_func =
-    gavl_video_scale_get_weight_func(opt, &(tab->factors_per_pixel));
+    gavl_video_scale_get_weight_func(opt, &tab->factors_per_pixel);
 
   num_tmp_factors = tab->factors_per_pixel;
   
@@ -191,7 +194,7 @@ void gavl_video_scale_table_init(gavl_video_scale_table_t * tab,
         break;
       }
     weight_func =
-      gavl_video_scale_get_weight_func(opt, &(tab->factors_per_pixel));
+      gavl_video_scale_get_weight_func(opt, &tab->factors_per_pixel);
     }
   
   //  fprintf(stderr, "gavl_video_scale_table_init: %f %f %d %d\n", 
@@ -590,8 +593,17 @@ void gavl_video_scale_table_cleanup(gavl_video_scale_table_t * tab)
 void gavl_video_scale_table_get_src_indices(gavl_video_scale_table_t * tab,
                                             int * start, int * size)
   {
-  *start = tab->pixels[0].index;
-  *size = tab->pixels[tab->num_pixels-1].index + tab->factors_per_pixel - *start;
+  if(!tab->pixels)
+    {
+    *start = 0;
+    *size = 0;
+    }
+  else
+    {
+    *start = tab->pixels[0].index;
+    *size = tab->pixels[tab->num_pixels-1].index + tab->factors_per_pixel -
+      *start;
+    }
   }
 
 void gavl_video_scale_table_shift_indices(gavl_video_scale_table_t * tab,
