@@ -1,7 +1,7 @@
 /*****************************************************************
  * gavl - a general purpose audio/video processing library
  *
- * Copyright (c) 2001 - 2010 Members of the Gmerlin project
+ * Copyright (c) 2001 - 2011 Members of the Gmerlin project
  * gmerlin-general@lists.sourceforge.net
  * http://gmerlin.sourceforge.net
  *
@@ -118,10 +118,13 @@ typedef const struct
 
 interlace_mode_tab_t interlace_mode_tab[] =
   {
+    { GAVL_INTERLACE_UNKNOWN,      "Unknown" },
     { GAVL_INTERLACE_NONE,         "None (Progressive)" },
     { GAVL_INTERLACE_TOP_FIRST,    "Top field first" },
     { GAVL_INTERLACE_BOTTOM_FIRST, "Bottom field first" },
-    { GAVL_INTERLACE_MIXED,        "Mixed" }
+    { GAVL_INTERLACE_MIXED,        "Mixed" },
+    { GAVL_INTERLACE_MIXED_TOP,    "Top first + progressive" },
+    { GAVL_INTERLACE_MIXED_BOTTOM, "Bottom first + progressive" }
   };
 
 static const int num_interlace_modes = sizeof(interlace_mode_tab)/sizeof(interlace_mode_tab[0]);
@@ -137,6 +140,36 @@ const char * gavl_interlace_mode_to_string(gavl_interlace_mode_t mode)
   return (const char*)0;
   }
 
+typedef const struct
+  {
+  gavl_framerate_mode_t mode;
+  char * name;
+  } framerate_mode_tab_t;
+
+framerate_mode_tab_t framerate_mode_tab[] =
+  {
+    { GAVL_FRAMERATE_UNKNOWN,      "Unknown" },
+    { GAVL_FRAMERATE_CONSTANT,     "Constant" },
+    { GAVL_FRAMERATE_VARIABLE,     "Variable" },
+    { GAVL_FRAMERATE_STILL,        "Still" },
+  };
+
+static const int num_framerate_modes = sizeof(framerate_mode_tab)/sizeof(framerate_mode_tab[0]);
+
+
+const char * gavl_framerate_mode_to_string(gavl_framerate_mode_t mode)
+  {
+  int i;
+  for(i = 0; i < num_framerate_modes; i++)
+    {
+    if(framerate_mode_tab[i].mode == mode)
+      return framerate_mode_tab[i].name;
+    }
+  return (const char*)0;
+  
+  }
+
+
 
 typedef struct
   {
